## START: Set by rpmautospec
## (rpmautospec version 0.7.3)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 2;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%bcond 	        hip 1
%bcond          ninja 1
#%%global	        prerelease beta
Name:           oidn
Version:        2.3.2
Release:        %autorelease %{?prerelease: -p -e %{prerelease}}
Summary:        Library of denoising filters for images rendered with ray tracing
License:        Apache-2.0
URL:            https://openimagedenoise.github.io/

Source0:        https://github.com/OpenImageDenoise/%{name}/releases/download/v%{version}%{?prerelease:-%{prerelease}}/%{name}-%{version}%{?prerelease:-%{prerelease}}.src.tar.gz

%if %{with hip}
# hipcc is clang based and the extra rpm induced gcc args confuse it
%global toolchain clang
# hipcc does not support some clang flags
%global build_cxxflags %(echo %{optflags} | sed -e 's/-fstack-protector-strong//' -e 's/-fcf-protection//')
%endif

# Library only available on x86_64
ExclusiveArch:  x86_64

BuildRequires:  cmake >= 3.13.0
# Enable HIP support
%if %{with hip}
BuildRequires:  hipcc
BuildRequires:  rocm-hip-devel
BuildRequires:  rocm-runtime
%endif
# Needed to remove rpath from apps
BuildRequires:  chrpath
%if %{with hip}
BuildRequires:  clang
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  ispc
%if %{with ninja}
BuildRequires:  ninja-build
%endif
BuildRequires:  pkgconfig(OpenImageIO)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(tbb)

%description
Intel Open Image Denoise is an open source library of high-performance, 
high-quality denoising filters for images rendered with ray tracing.

%package        libs
Summary:        Libraries for %{name}

%description    libs
The %{name}-libs package contains shared library for %{name}.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}

%description devel
The %{name}-devel package contains libraries and header files for developing
applications that use %{name}.

%package        docs
Summary:        Documentation for %{name}
Requires:       %{name}-libs%{?_isa} = %{version}-%{release}
BuildArch:      noarch

%description docs
The %{name}-docs package contains documentation for %{name}.

%prep
%autosetup -n %{name}-%{version}%{?prerelease:-%{prerelease}}

%build
%cmake \
%if %{with ninja}
    -G Ninja \
%endif
    -DCMAKE_VERBOSE_MAKEFILE:BOOL=TRUE \
%if %{with hip}
    -DOIDN_DEVICE_HIP=ON \
    -DOIDN_DEVICE_HIP_COMPILER=%{_bindir}/hipcc \
    -DROCM_PATH=%{_libdir}
%endif
%cmake_build

%install
%cmake_install

# Remove rpath
chrpath --delete %{buildroot}%{_bindir}/%{name}{Denoise,Test,Benchmark}
chrpath --delete %{buildroot}%{_libdir}/libOpenImageDenoise{,_core,_device_cpu}.so.*
%if %{with hip}
chrpath --delete %{buildroot}%{_libdir}/libOpenImageDenoise_device_hip.so.*
%endif

# Remove duplicated documentation
rm -rf %{buildroot}%{_docdir}/OpenImageDenoise

%files
%license LICENSE.txt
%doc CHANGELOG.md 
%{_bindir}/%{name}{Denoise,Test,Benchmark}

%files libs
%{_libdir}/libOpenImageDenoise{,_core,_device_cpu}.so.2
%{_libdir}/libOpenImageDenoise{,_core,_device_cpu}.so.%{version}
%if %{with hip}
%{_libdir}/libOpenImageDenoise_device_hip.so.%{version}
%endif

%files docs
%doc README.md readme.pdf 

%files devel
%{_libdir}/cmake/OpenImageDenoise-%{version}/*.cmake
%{_includedir}/OpenImageDenoise
%{_libdir}/libOpenImageDenoise.so

%changelog
## START: Generated by rpmautospec
* Fri Jan 17 2025 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_42_Mass_Rebuild

* Thu Jan 16 2025 Luya Tshimbalanga <luya@fedoraproject.org> - 2.3.2-1
- Update to 2.3.2 (rhbz#2337565)

* Wed Nov 13 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 2.3.1-1
- Update to 2.3.1 (rhbz#2325495)

* Sun Sep 22 2024 Tom Rix <Tom.Rix@amd.com> - 2.3.0-5
- Enable hip

* Thu Jul 18 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.3.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_41_Mass_Rebuild

* Tue Jun 18 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 2.3.0-3
- Update to 2.3.0 (rhbz#2292770)

* Tue May 28 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 2.3.0-0.2.beta
- Rebuild for ispc 1.24.0

* Sun May 05 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 2.3.0-0.1.beta
- Update to 2.3.0 beta (rhbz#2269787)

* Sun Mar 17 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 2.2.2-1
- Update to 2.2.2 (#2269787)

* Sun Mar 03 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 2.2.1-1
- Update to 2.2.1 (rhbz#2267055)

* Sat Feb 17 2024 Luya Tshimbalanga <luya@fedoraproject.org> - 2.2.0-1
- Update to 2.2.0 (rhbz#2262488)

* Tue Jan 30 2024 Richard Shaw <hobbes1069@gmail.com> - 2.1.0-5
- Rebuild for OpenImageIO 2.5.x.

* Thu Jan 25 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Sun Jan 21 2024 Fedora Release Engineering <releng@fedoraproject.org> - 2.1.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_40_Mass_Rebuild

* Wed Jan 17 2024 Jonathan Wakely <jwakely@redhat.com> - 2.1.0-2
- Rebuilt for TBB 2021.11

* Fri Oct 13 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 2.1.0-1
- Update to 2.1.0 (rhbz#2243422)

* Thu Jul 20 2023 Fedora Release Engineering <releng@fedoraproject.org> - 2.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jun 27 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 2.0.1-1
- Update to 2.0.1 (rhbz#2209815)

* Fri Jun 02 2023 Ali Erdinc Koroglu <aekoroglu@linux.intel.com> - 2.0.0-2
- ahead-of-time (only for development) disabled and lib versioning added

* Tue May 30 2023 Luya Tshimbalanga <luya@fedoraproject.org> - 2.0.0-1
- Update to oidn 2.0.0

* Thu Jan 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.3-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Fri Jul 22 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Sun Jul 10 2022 Daan De Meyer <daan.j.demeyer@gmail.com> - 1.4.3-2
- Remove explicit build directory argument from cmake call

* Tue Feb 22 2022 Luya Tshimbalanga <luya@fedoraproject.org> - 1.4.3-1
- Update to oidn 1.4.3 (#2020201)

* Thu Jan 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Thu Jul 22 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_35_Mass_Rebuild

* Wed Jun 23 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1.4.1-1
- Update to 1.4.1 Resolves rhbz#1975015

* Wed May 19 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1.4.0-1
- Update to 1.4.0 Drop temporary patch from upstraem Resolves rhbz#1961760

* Tue May 11 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1.3.0-6
- Patch from upstream devel branch addressing glibc change Fixes
  rhbz#1959312 Resolves: fedora#1945579

* Tue May 11 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1.3.0-5
- Patch from upstream devel branch addressing glibc change Fixes
  rhbz#1959312 Resolves: fedora#1945579

* Tue May 11 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1.3.0-4
- Patch from upstream devel branch addressing glibc change Fixes
  rhbz#1959312 Resolves: fedora#1945579

* Mon May 10 2021 Jonathan Wakely <jwakely@redhat.com> - 1.3.0-3
- Rebuilt for removed libstdc++ symbols (#1937698)

* Tue Mar 30 2021 Jonathan Wakely <jwakely@redhat.com> - 1.3.0-2
- Rebuilt for removed libstdc++ symbol (#1937698)

* Fri Feb 05 2021 Luya Tshimbalanga <luya@fedoraproject.org> - 1.3.0-1
- Update to 1.3.0

* Tue Jan 26 2021 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_34_Mass_Rebuild

* Wed Dec 02 2020 Luya Tshimbalanga <luya@fedoraproject.org> - 1.2.4-1
- Update to 1.2.4

* Mon Sep 14 2020 Luya Tshimbalanga <luya@fedoraproject.org> - 1.2.3-1
- Update to 1.2.3 Follow new Fedora cmake guideline

* Thu Aug 20 2020 Simone Caronni <negativo17@gmail.com> - 1.2.2-4
- Move cmake files to devel subpackage

* Sat Aug 01 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.2-3
- Second attempt - Rebuilt for
  https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Tue Jul 28 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_33_Mass_Rebuild

* Mon Jul 20 2020 Luya Tshimbalanga <luya@fedoraproject.org> - 1.2.2-1
- Update to 1.2.2 (#1855832) Add OpenImageIO dependency

* Sun Jun 21 2020 Luya Tshimbalanga <luya@fedoraproject.org> - 1.2.1-1
- Update to 1.2.1

* Sat Apr 11 2020 Luya Tshimbalanga <luya@fedoraproject.org> - 1.2.0-1
- Update to 1.2.0 Add ispc and redhat-rpm-config depedencies

* Wed Jan 29 2020 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_32_Mass_Rebuild

* Thu Oct 17 2019 Luya Tshimbalanga <luya@fedoraproject.org> - 1.1.0-1
- Update to 1.1.0

* Sat Aug 17 2019 Luya Tshimbalanga <luya@fedoraproject.org> - 1.0.0-1
- Update to 1.0.0 Use pkgconfig for Python 3

* Thu Jul 25 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.9.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_31_Mass_Rebuild

* Thu May 09 2019 Luya Tshimbalanga <luya@fedoraproject.org> - 0.9.0-1
- Update to 0.9.0

* Tue Apr 02 2019 Luya Tshimbalanga <luya@fedoraproject.org> - 0.8.2-1
- Use spaces on line 47 Make -doc subpackage noarch Make -doc subpackage
  requiring main package
## END: Generated by rpmautospec
